@@ -10,11 +10,11 @@ Acme::MLX - The great new Acme::MLX!
 
 =head1 VERSION
 
-Version 0.02_03
+Version 0.01
 
 =cut
 
-our $VERSION = '0.02_03';
+our $VERSION = '0.01';
 
 
 =head1 SYNOPSIS
@@ -35,18 +35,11 @@ if you don't export anything, such as for a purely object-oriented module.
 
 =head1 SUBROUTINES/METHODS
 
-=head2 sum( LIST_OF_NUMBERS )
-
-Returns the sum of the numbers
+=head2 function1
 
 =cut
 
-sub sum {
-    my $sum = 0;
-
-    $sum += $_ for @_;
-
-    $sum;
+sub function1 {
 }
 
 =head2 function2
